﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Microsoft.Devices.Sensors;

namespace PhoneAppSensorsBall
{
    /// <summary>
    /// Application illustrates how to use the accelerometer sensor.
    /// Remeber to add the Microsoft.Devices.Sensors.dll file to the list of References
    /// (right click and select "Add Reference...").
    /// </summary>
    public partial class MainPage : PhoneApplicationPage
    {

        // Access to the accelerometer sensor
        private Accelerometer accelerometer;


        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Disable the frame rate counter (tiny numbers on the right side of the screen)
            Application.Current.Host.Settings.EnableFrameRateCounter = false;


            // Initialize accelerometer
            this.accelerometer = new Accelerometer();

            // Subscribe for all events that occur when the accelerometer
            // values change (-> movement of the device)
            this.accelerometer.ReadingChanged += new EventHandler<AccelerometerReadingEventArgs>(accelerometer_ReadingChanged);


            // Start the accelerometer sensor
            this.accelerometer.Start();
        }



        // Handler method for update events from the accelerometer
        void accelerometer_ReadingChanged(object sender, AccelerometerReadingEventArgs e)
        {
            Deployment.Current.Dispatcher.BeginInvoke(() =>
            {
                // Below is the code for animating the ball depending 
                // on accelerometer values
                
                // 1) The default distance the ellipse moves in pixels
                double distance = 30;

                // 2) Calculate the acceleration factor. The Z-axis is the normal vector
                //    of the phone display. Therefore, the higher the Z value of the acceleration sensor,
                //    the more the display is tilted to either side
                double accelerationFactor = Math.Abs(e.Z) == 0 ? 0.1 : Math.Abs(e.Z);

                // 3) Calculate the new position of the ellipse depending on the
                //    acceleration factor
                double positionX = (double)this.ellipse.GetValue(Canvas.LeftProperty) +
                    distance * e.X / accelerationFactor;
                double positionY = (double)this.ellipse.GetValue(Canvas.TopProperty) -
                    distance * e.Y / accelerationFactor;

                // 4) Limit the values of the X and Y position, so the ellipse does not disappear
                //    at any side of the screen
                positionX = this.Limit(positionX, 0, this.canvas.ActualWidth - this.ellipse.ActualWidth);
                positionY = this.Limit(positionY, 0, this.canvas.ActualHeight - this.ellipse.ActualHeight);

                // 5) Set the new position of the ellipse
                this.ellipse.SetValue(Canvas.LeftProperty, positionX);
                this.ellipse.SetValue(Canvas.TopProperty, positionY);
            });
        }



        // Limit double value between minimum and maximum
        private double Limit(double value, double min, double max)
        {
            if (value < min) return min;
            else if (value > max) return max;
            else return value;
        }
    }
}